@@ -575,10 +575,10 @@ class TestRowProParser:
         row=rowingdata.rowingdata(df=r.df)
         assert_equal(row.number_of_rows,988)
         totaldist=row.df['cum_dist'].max()
-        assert_equal(totaldist,10000)
+        assert_equal(int(totaldist),9994)
         assert_equal(row.rowdatetime,datetime.datetime(2016,3,15,19,49,48,863000,utc))
         totaltime=row.df['TimeStamp (sec)'].max()-row.df['TimeStamp (sec)'].min()
-        assert_equal(int(10*totaltime),22653)
+        assert_equal(int(10*totaltime),22640)
         checks = row.check_consistency()
         assert_equal(checks['velo_time_distance'],True)
         #         assert_equal(checks['velo_valid'],True)
@@ -604,12 +604,12 @@ class TestRowProParserIntervals:
         assert_equal(rowingdata.get_file_type(csvfile),'rp')
         r=rowingdata.RowProParser(csvfile=csvfile)
         row=rowingdata.rowingdata(df=r.df)
-        assert_equal(row.number_of_rows,1674)
+        assert_equal(row.number_of_rows,1673)
         totaldist=row.df['cum_dist'].max()
-        assert_equal(int(totaldist),19026)
+        assert_equal(int(totaldist),19002)
         assert_equal(row.rowdatetime,datetime.datetime(2016,1,12,19,23,10,878000,utc))
         totaltime=row.df['TimeStamp (sec)'].max()-row.df['TimeStamp (sec)'].min()
-        assert_equal(int(totaltime),4800)
+        assert_equal(int(totaltime),4793)
         checks = row.check_consistency()
         assert_equal(checks['velo_time_distance'],True)
         #        assert_equal(checks['velo_valid'],True)
@@ -652,7 +652,7 @@ class TestCurveData:
         r = rowingdata.RowPerfectParser(file)
         row = rowingdata.rowingdata(df=r.df)
         df = row.get_instroke_data('curve_data')
-        assert_equal(len(df),468)
+        assert_equal(len(df),467)
         cs = row.get_instroke_columns()
         assert_equal(len(cs),1)
         assert_equal(cs[0],'curve_data')
@@ -665,6 +665,7 @@ class TestCurveData:
         cs = row.get_instroke_columns()
         assert_equal(len(cs),2)
         assert_equal(cs[0],'boat accelerator curve')
+        #plt = row.get_plot_instroke('boat accelerator curve')
 
 
 class TestFITParser:
